@@ -67,7 +67,7 @@ void MessageQueueJobTest::initTestCase()
     // check that outbox is empty
     SpecialMailCollectionsRequestJob *rjob = new SpecialMailCollectionsRequestJob(this);
     rjob->requestDefaultCollection(SpecialMailCollections::Outbox);
-    QSignalSpy spy(rjob, SIGNAL(result(KJob *)));
+    QSignalSpy spy(rjob, SIGNAL(result(KJob*)));
     QVERIFY(spy.wait(10000));
     verifyOutboxContents(0);
 }
@@ -136,11 +136,10 @@ void MessageQueueJobTest::testValidMessages()
 
 void MessageQueueJobTest::testInvalidMessages()
 {
-    MessageQueueJob *job = nullptr;
     Message::Ptr msg;
 
     // without message
-    job = new MessageQueueJob;
+    MessageQueueJob *job = new MessageQueueJob;
     job->transportAttribute().setTransportId(TransportManager::self()->defaultTransportId());
     job->addressAttribute().setTo(SPAM_ADDRESS);
     QVERIFY(!job->exec());
